@@ -9,8 +9,8 @@
 project = "Spyctl"
 copyright = "2023, SPYDERBAT, Inc., All Rights Reserved"
 author = "Spyderbat"
-release = "0.1"
-version = "0.1.0"
+release = "0.9"
+version = "0.9.0"
 
 
 # -- General configuration ---------------------------------------------------
@@ -34,3 +34,5 @@ exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
 
 html_theme = "sphinx_rtd_theme"
 html_static_path = ["_static"]
+html_favicon = "_static/sb-logo.png"
+html_logo = "_static/sb-logo-sidebar.png"
